@@ -40,7 +40,7 @@ OptimizerAsyncGridSearch = R6Class("OptimizerAsyncGridSearch",
         id = "async_grid_search",
         param_set = param_set,
         param_classes = c("ParamLgl", "ParamInt", "ParamDbl", "ParamFct"),
-        properties = c("dependencies", "single-crit", "multi-crit"),
+        properties = c("dependencies", "single-crit", "multi-crit", "async"),
         packages = "rush",
         label = "Asynchronous Grid Search",
         man = "bbotk::mlr_optimizers_async_grid_search"
