@@ -2,7 +2,7 @@ test_that("TerminatorNone works", {
   terminators = trms(c("evals", "none"))
 
   terminators[[1]]$param_set$values$n_evals = 10L
-  expect_output(print(terminators[[2]]), "TerminatorNone")
+  expect_snapshot(terminators)
   terminator = TerminatorCombo$new(terminators)
   inst = MAKE_INST_2D(terminator)
   a = random_search(inst, batch_size = 1L)
@@ -11,7 +11,7 @@ test_that("TerminatorNone works", {
 
 test_that("TerminatorNone works with empty archive", {
   terminator = TerminatorNone$new()
-  archive = Archive$new(ps(x = p_dbl()), ps(y = p_dbl(tags = "minimize")))
+  archive = ArchiveBatch$new(ps(x = p_dbl()), ps(y = p_dbl(tags = "minimize")))
   expect_false(terminator$is_terminated(archive))
 })
 
